from setuptools import setup

setup(name='iduate-probability',
      version='0.1',
      description='probability distributions - Gaussian, Binomial',
      packages=['distributions'],
      zip_safe=False)
